summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/autolayout/autolayouter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/autolayout/autolayouter.cpp')
-rw-r--r--umbrello/umbrello/autolayout/autolayouter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/autolayout/autolayouter.cpp b/umbrello/umbrello/autolayout/autolayouter.cpp
index 802bc438..f70fd195 100644
--- a/umbrello/umbrello/autolayout/autolayouter.cpp
+++ b/umbrello/umbrello/autolayout/autolayouter.cpp
@@ -13,11 +13,11 @@
***************************************************************************/
#include "autolayouter.h"
-namespace Autotqlayout {
+namespace Autolayout {
-void Autolayouter::autotqlayout( UMLView * v )
+void Autolayouter::autolayout( UMLView * v )
{
setCanvas(v);
setGraph(v);
@@ -25,5 +25,5 @@ void Autolayouter::autotqlayout( UMLView * v )
updateView(v);
}
-} // end namespace Autotqlayout
+} // end namespace Autolayout